jaclearn.rl.envs.maze.taxi
==========================

.. automodule:: jaclearn.rl.envs.maze.taxi

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      CustomLavaWorldTaxiEnv
      CustomTaxiEnv
   
   

   
   
   

   
   
   








.. rubric:: Class CustomLavaWorldTaxiEnv
.. autoclass:: CustomLavaWorldTaxiEnv
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class CustomTaxiEnv
.. autoclass:: CustomTaxiEnv
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







